@@ -2,29 +2,23 @@ package HTTP::MobileAgent;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.26_1';
+$VERSION = 0.01;
 
 use HTTP::MobileAgent::Request;
 
 require HTTP::MobileAgent::DoCoMo;
 require HTTP::MobileAgent::JPhone;
 require HTTP::MobileAgent::EZweb;
-require HTTP::MobileAgent::AirHPhone;
 require HTTP::MobileAgent::NonMobile;
-require HTTP::MobileAgent::Display;
 
 use vars qw($MobileAgentRE);
 # this matching should be robust enough
 # detailed analysis is done in subclass's parse()
 my $DoCoMoRE = '^DoCoMo/\d\.\d[ /]';
-my $JPhoneRE = '^(?i:J-PHONE/\d\.\d)';
-my $VodafoneRE = '^Vodafone/\d\.\d';
-my $VodafoneMotRE = '^MOT-';
-my $SoftBankRE = '^SoftBank/\d\.\d';
-my $SoftBankCrawlerRE = '^Nokia[^/]+/\d\.\d';
-my $EZwebRE  = '^(?:KDDI-[A-Z]+\d+[A-Z]? )?UP\.Browser\/';
-my $AirHRE = '^Mozilla/3\.0\((?:WILLCOM|DDIPOCKET)\;';
-$MobileAgentRE = qr/(?:($DoCoMoRE)|($JPhoneRE|$VodafoneRE|$VodafoneMotRE|$SoftBankRE|$SoftBankCrawlerRE)|($EZwebRE)|($AirHRE))/;
+my $JPhoneRE = '^J-PHONE/\d\.\d';
+my $EZwebRE  = '^(?:KDDI-[A-Z]+\d+ )?UP\.Browser\/';
+
+$MobileAgentRE = qr/(?:($DoCoMoRE)|($JPhoneRE)|($EZwebRE))/;
 
 sub new {
     my($class, $stuff) = @_;
@@ -32,17 +26,14 @@ sub new {
 
     # parse UA string
     my $ua = $request->get('User-Agent');
-    my $sub = 'NonMobile';
-    if ($ua =~ /$MobileAgentRE/) {
-        $sub = $1 ? 'DoCoMo' : $2 ? 'JPhone' : $3 ? 'EZweb' :  'AirHPhone';
-    }
+    $ua =~ /$MobileAgentRE/;
+    my $sub = $1 ? 'DoCoMo' : $2 ? 'JPhone' : $3 ? 'EZweb' : 'NonMobile';
 
     my $self = bless { _request => $request }, "$class\::$sub";
     $self->parse;
     return $self;
 }
 
-
 sub user_agent {
     my $self = shift;
     $self->get_header('User-Agent');
@@ -55,17 +46,14 @@ sub get_header {
 
 # should be implemented in subclasses
 sub parse { die }
-sub _make_display { die }
 
 sub name  { shift->{name} }
 
-sub display {
-    my $self = shift;
-    unless ($self->{display}) {
-	$self->{display} = $self->_make_display;
-    }
-    return $self->{display};
-}
+# Here sare defaults
+sub is_mobile     { 1 }
+sub is_docomo     { 0 }
+sub is_j_phone    { 0 }
+sub is_ezweb      { 0 }
 
 # utility for subclasses
 sub make_accessors {
@@ -81,30 +69,10 @@ sub no_match {
     require Carp;
     Carp::carp($self->user_agent, ": no match. Might be new variants. ",
 	       "please contact the author of HTTP::MobileAgent!") if $^W;
+    bless $self, 'HTTP::MobileAgent::NonMobile';
+    $self->parse;
 }
 
-sub is_docomo  { 0 }
-sub is_j_phone { 0 }
-sub is_vodafone { 0 }
-sub is_softbank { 0 }
-sub is_ezweb   { 0 }
-sub is_airh_phone { 0 }
-sub is_non_mobile { 0 }
-sub is_tuka { 0 }
-
-sub is_wap1 {
-    my $self = shift;
-    $self->is_ezweb && ! $self->is_wap2;
-}
-
-sub is_wap2 {
-    my $self = shift;
-    $self->is_ezweb && $self->xhtml_compliant;
-}
-
-sub carrier { undef }
-sub carrier_longname { undef }
-
 1;
 __END__
 
@@ -125,9 +93,9 @@ HTTP::MobileAgent - HTTP mobile user agent string parser
       # or if ($agent->isa('HTTP::MobileAgent::DoCoMo'))
       # it's NTT DoCoMo i-mode.
       # see what's available in H::MA::DoCoMo
-  } elsif ($agent->is_vodafone) {
-      # it's Vodafone(J-Phone).
-      # see what's available in H::MA::Vodafone
+  } elsif ($agent->is_j_phone) {
+      # it's J-Phone.
+      # see what's available in H::MA::JPhone
   } elsif ($agent->is_ezweb) {
       # it's KDDI/EZWeb.
       # see what's available in H::MA::EZweb
@@ -136,9 +104,6 @@ HTTP::MobileAgent - HTTP mobile user agent string parser
       # $agent is H::MA::NonMobile
   }
 
-  my $display = $agent->display;	# HTTP::MobileAgent::Display
-  if ($display->color) { ... }
-
 =head1 DESCRIPTION
 
 HTTP::MobileAgent parses HTTP_USER_AGENT strings of (mainly Japanese)
@@ -177,26 +142,17 @@ returns User-Agent string.
 
 returns User-Agent name like 'DoCoMo'.
 
-=item is_docomo, is_vodafone(is_j_phone, is_softbank), is_ezweb, is_wap1, is_wap2, is_tuka,is_non_mobile
+=item is_mobile
 
-   if ($agent->is_docomo) { }
+  if ($agent->is_mobile) {
+      # it's really a mobile agent
+  }
 
-returns if the agent is DoCoMo, Vodafone(J-Phone) or EZweb.
+returns if the agent is mobile or not.
 
-=item carrier
+=item is_docomo, is_j_phone, is_ezweb
 
-  print "carrier: ", $agent->carrier;
-
-=item carrier_longname
-
-  print "carrier_longname: ", $agent->carrier_longname;
-
-=item display
-
-  my $display = $agent->display;
-
-returns HTTP::MobileAgent::Display object. See
-L<HTTP::MobileAgent::Display> for details.
+returns if the agent is DoCoMo or J-Phone or EZWeb.
 
 =back
 
@@ -232,29 +188,18 @@ If you have any idea / request for this module to add new subclass,
 I'm open to the discussion or (more preferable) patches. Feel free to
 mail me.
 
-=head1 OTHER LANGUAGE BINDINGS
-
-This module is now ported to PHP as Net::UserAgent::Mobile by Atsuhiro
-KUBO.  See http://pear.php.net/package-info.php?pacid=180 for details.
-
 =head1 AUTHOR
 
-Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt> is the original author and wrote almost all the code.
-
-with contributions of Satoshi Tanimoto E<lt>tanimoto@cpan.orgE<gt> and Yoshiki Kurihara E<lt>kurihara@cpan.orgE<gt>
-
-=head1 LICENSE
+Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=head1 MAIN
-
 =head1 SEE ALSO
 
-L<HTTP::MobileAgent::DoCoMo>, L<HTTP::MobileAgent::Vodafone>, L<HTTP::MobileAgent::JPhone>,
+L<HTTP::MobileAgent::DoCoMo>, L<HTTP::MobileAgent::JPhone>,
 L<HTTP::MobileAgent::EZweb>, L<HTTP::MobileAgent::NonMobile>,
-L<HTTP::MobileAgent::Display>, L<HTTP::BrowserDetect>
+L<HTTP::BrowserDetect>
 
 Reference URL for specification is listed in Pods for each subclass.
 
