@@ -1,31 +1,12 @@
 package HTTP::MobileAgent::EZweb;
 
 use strict;
-use vars qw($VERSION);
-$VERSION = 0.19;
-
 use base qw(HTTP::MobileAgent);
 
 __PACKAGE__->make_accessors(
-    qw(version model device_id server xhtml_compliant comment)
+    qw(version device_id server xhtml_compliant comment)
 );
 
-sub is_ezweb { 1 }
-
-sub carrier { 'E' }
-
-sub carrier_longname { 'EZweb' }
-
-sub is_tuka {
-  my $self = shift;
-  my $tuka = substr($self->device_id, 2, 1);
-  if($self->is_wap2){
-      return 1 if $tuka eq 'U';
-  } else {
-      return 1 if $tuka eq 'T';
-  }
-}
-
 sub parse {
     my $self = shift;
     my $ua = $self->user_agent;
@@ -38,6 +19,7 @@ sub parse {
 	my($name, $version) = split m!/!, $browser;
 	$self->{name} = $name;
 	$self->{version} = "$version $opt";
+
 	$self->{server} = $server;
     }
     else {
@@ -52,21 +34,9 @@ sub parse {
 	    $self->{comment} = $comment;
 	}
     }
-    $self->{model} = $self->{device_id};
 }
 
-sub _make_display {
-    my $self = shift;
-    my($width, $height) = split /,/, $self->get_header('x-up-devcap-screenpixels');
-    my $depth = (split /,/, $self->get_header('x-up-devcap-screendepth'))[0];
-    my $color = $self->get_header('x-up-devcap-iscolor');
-    return HTTP::MobileAgent::Display->new(
-	width  => $width,
-	height => $height,
-	color  => (defined $color && $color eq '1'),
-	depth  => 2 ** $depth,
-    );
-}
+sub is_ezweb { 1 }
 
 1;
 __END__
@@ -143,7 +113,11 @@ returns if the agent is XHTML compliant.
 
 =item *
 
-Spec information support listed in
+Parse C<X-UP-*> HTTP headers.
+
+=over 4
+
+Spec information support listed in 
 http://www.au.kddi.com/ezfactory/tec/spec/new_win/ezkishu.html
 
 (Patches are always welcome ;))
