@@ -1,29 +1,16 @@
 package HTTP::MobileAgent::NonMobile;
 
 use strict;
-use vars qw($VERSION);
-$VERSION = 0.02;
 use base qw(HTTP::MobileAgent);
 
-__PACKAGE__->make_accessors(
-    qw(model device_id)
-);
-
 sub parse {
     my $self = shift;
     my($name, $version) = split m!/!, $self->user_agent;
     $self->{name} = $name;
     $self->{version} = $version;
-    $self->{device_id} = '';
-	$self->{model} = '';
 }
 
-sub is_non_mobile { 1 }
-
-sub carrier { 'N' }
-
-sub carrier_longname { 'NonMobile' }
-
+sub is_mobile { 0 }
 
 1;
 __END__
@@ -48,6 +35,8 @@ implements non-mobile or unimplemented user agents.
 
 See L<HTTP::MobileAgent/"METHODS"> for common methods.
 
+=back
+
 =head1 AUTHOR
 
 Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>
